@@ -1,6 +1,10 @@
 from . import mixin_api
 from . import mixin_bot_api
-__VERSION__ = '0.2.4'
+from . import _mixin
+
+__VERSION__ = '0.2.5'
+
+_mixin.init()
 
 default_api = mixin_api.MixinApi()
 
