@@ -1,9 +1,18 @@
 package main
 
+//#include <stdint.h>
 // static char* get_p(char **pp, int i)
 // {
 //	    return pp[i];
 // }
+//typedef char *(*fn_malloc)(uint64_t size);
+//static fn_malloc g_malloc = NULL;
+//static void set_malloc_fn(fn_malloc fn) {
+//	g_malloc = fn;
+//}
+//static char *cmalloc(uint64_t size) {
+//	return 	g_malloc(size);
+//}
 import "C"
 
 import (
@@ -48,7 +57,7 @@ type CreateAddressParams struct {
 func renderData(data interface{}) *C.char {
 	ret := map[string]interface{}{"data": data}
 	result, _ := json.Marshal(ret)
-	return C.CString(string(result))
+	return CString(string(result))
 }
 
 func renderError(err error) *C.char {
@@ -56,11 +65,20 @@ func renderError(err error) *C.char {
 	error := fmt.Sprintf("[error] in %s[%s:%d] %v", runtime.FuncForPC(pc).Name(), fn, line, err)
 	ret := map[string]interface{}{"error": error}
 	result, _ := json.Marshal(ret)
-	return C.CString(string(result))
+	return CString(string(result))
+}
+
+func CString(s string) *C.char {
+	p := C.cmalloc(C.uint64_t(len(s) + 1))
+	pp := (*[1 << 30]byte)(unsafe.Pointer(p))
+	copy(pp[:], s)
+	pp[len(s)] = 0
+	return (*C.char)(p)
 }
 
 //export Init
-func Init() {
+func Init(malloc C.fn_malloc) {
+	C.set_malloc_fn(malloc)
 	log.SetFlags(log.LstdFlags | log.Lshortfile)
 }
 
@@ -903,7 +921,7 @@ func NewGhostKeys(_seed *C.char, accounts *C.char, outputs C.int) *C.char {
 
 //export GetMixinVersion
 func GetMixinVersion() *C.char {
-	return C.CString(config.BuildVersion)
+	return CString(config.BuildVersion)
 }
 
 //export GenerateRandomSeed
@@ -913,7 +931,7 @@ func GenerateRandomSeed() *C.char {
 	if err != nil {
 		return renderError(err)
 	}
-	return C.CString(hex.EncodeToString(seed))
+	return CString(hex.EncodeToString(seed))
 }
 
 //func BatchVerify(msg []byte, keys []*Key, sigs []*Signature) bool
